% Autor: Wiebke Petersen
% Datum: 20.04.2019

:- module(syntaxChecker,
          [check_sentence/2]).

:- use_module(comsemPredicates,[removeAll/3,memberList/2,compose/3]).

check_sentence(Formula,Model):-
    is_formula(Formula,[],Model).

check_evaluability(Formula,Model,Assignment):-
    is_formula(Formula,FreeVariables,Model),
    setof(V,memberList(g(V,_),Assignment),AssignedVariables),
    setof(V,memberList(V,FreeVariables),AssignedVariables).
    
%is_formula(Formula,FV,M)

is_formula(Formula,FV,model(_,F)):-
      compose(Formula,P,[A]),
      memberList(f(1,P,_),F),
      is_term(A,F,FV).

is_formula(Formula,FV,model(_,F)):-
      compose(Formula,P,[A1,A2]),
      memberList(f(2,P,_),F),
      is_term(A1,F,FV1),
      is_term(A2,F,FV2),
      append(FV1,FV2,FV).

is_formula(eq(A1,A2),FV,model(_,F)):-
      is_term(A1,F,FV1),
      is_term(A2,F,FV2),
      append(FV1,FV2,FV).

is_formula(and(F1,F2),FV,M):-
      is_formula(F1,FV1,M),
      is_formula(F2,FV2,M),
      append(FV1,FV2,FV).
      
is_formula(or(F1,F2),FV,M):-
      is_formula(F1,FV1,M),
      is_formula(F2,FV2,M),
      append(FV1,FV2,FV).

is_formula(imp(F1,F2),FV,M):-
      is_formula(F1,FV1,M),
      is_formula(F2,FV2,M),
      append(FV1,FV2,FV).

is_formula(not(F),FV,M):-
      is_formula(F,FV,M).

is_formula(some(X,F),FVNew,M):-
      var(X),
      is_formula(F,FV,M),
      removeAll(X,FV,FVNew).

is_formula(all(X,F),FVNew,M):-
      var(X),
      is_formula(F,FV,M),
      removeAll(X,FV,FVNew).

is_term(A,_,[A]):-
      var(A).

is_term(A,F,[]):-
      not(var(A)),
      memberList(f(0,A,_),F).

